// sales-card.component.ts
import { Component, Input, Output, EventEmitter } from '@angular/core';
import { CommonModule } from '@angular/common';

@Component({
  selector: 'app-sales-card',
  standalone: true,
  imports: [CommonModule],
  template: `
    <div class="card" [ngClass]="sales.level" (click)="selectCard()">
      <!-- 其他内容保持不变 -->
      <div class="card-footer">
        <button class="permission-btn btn-edit" (click)="onEditPermission($event)">
          <i class="fas fa-user-cog"></i> 权限管理
        </button>
        <button class="permission-btn btn-details">
          <i class="fas fa-chart-bar"></i> 业绩详情
        </button>
      </div>
    </div>
  `,
  styles: [`
    .card {
      background: rgba(255, 255, 255, 0.85);
      backdrop-filter: blur(10px);
      border-radius: 20px;
      border: 1px solid rgba(255, 255, 255, 0.2);
      overflow: hidden;
      box-shadow: 0 8px 32px rgba(31, 38, 135, 0.15);
      transition: all 0.3s ease;
      color: #0f172a;
    }
    
    .card:hover {
      transform: translateY(-5px);
      box-shadow: 0 12px 20px rgba(31, 38, 135, 0.2);
    }
    
    .card-header {
      padding: 20px;
      display: flex;
      align-items: center;
      gap: 15px;
      border-bottom: 1px solid rgba(0, 0, 0, 0.05);
      position: relative;
    }
    
    .card-header::before {
      content: '';
      position: absolute;
      top: 0;
      left: 0;
      right: 0;
      height: 4px;
    }
    
    .rookie .card-header::before { background: linear-gradient(90deg, #60a5fa, #3b82f6); }
    .silver .card-header::before { background: linear-gradient(90deg, #cbd5e1, #94a3b8); }
    .gold .card-header::before { background: linear-gradient(90deg, #fcd34d, #f59e0b); }
    .platinum .card-header::before { background: linear-gradient(90deg, #a5b4fc, #818cf8); }
    .diamond .card-header::before { background: linear-gradient(90deg, #67e8f9, #22d3ee); }
    
    .avatar {
      width: 60px;
      height: 60px;
      border-radius: 50%;
      overflow: hidden;
      border: 3px solid white;
      box-shadow: 0 4px 6px rgba(0, 0, 0, 0.1);
    }
    
    .avatar img {
      width: 100%;
      height: 100%;
      object-fit: cover;
    }
    
    .user-info {
      flex: 1;
    }
    
    .user-info h3 {
      font-size: 18px;
      font-weight: 700;
      margin-bottom: 5px;
      color: #0f172a;
    }
    
    .user-info p {
      font-size: 14px;
      color: #64748b;
    }
    
    .user-tag {
      padding: 4px 12px;
      border-radius: 20px;
      font-size: 12px;
      font-weight: 600;
      margin-top: 5px;
      display: inline-block;
    }
    
    .card-body {
      padding: 20px;
      display: flex;
      flex-direction: column;
      gap: 15px;
    }
    
    .stats {
      display: flex;
      justify-content: space-between;
      text-align: center;
    }
    
    .stat {
      flex: 1;
    }
    
    .stat-value {
      font-size: 20px;
      font-weight: 700;
      margin-bottom: 5px;
    }
    
    .stat-label {
      font-size: 12px;
      color: #64748b;
    }
    
    .progress-container {
      margin-top: 5px;
    }
    
    .progress-label {
      display: flex;
      justify-content: space-between;
      font-size: 12px;
      color: #64748b;
      margin-bottom: 5px;
    }
    
    .progress-bar {
      height: 8px;
      background: #e2e8f0;
      border-radius: 10px;
      overflow: hidden;
    }
    
    .progress {
      height: 100%;
      border-radius: 10px;
    }
    
    .card-footer {
      padding: 15px 20px;
      background: rgba(241, 245, 249, 0.7);
      display: flex;
      justify-content: space-between;
      border-top: 1px solid rgba(0, 0, 0, 0.05);
    }
    
    .permission-btn {
      padding: 8px 15px;
      border-radius: 8px;
      font-size: 12px;
      font-weight: 600;
      cursor: pointer;
      display: flex;
      align-items: center;
      gap: 5px;
      border: none;
      transition: all 0.2s ease;
    }
    
    .permission-btn:hover {
      transform: translateY(-2px);
    }
    
    .btn-edit {
      background: linear-gradient(135deg, #a5b4fc, #818cf8);
      color: white;
    }
    
    .btn-details {
      background: rgba(203, 213, 225, 0.5);
      color: #0f172a;
    }
  `]
})
export class SalesCardComponent {
  @Input() sales: any;
  @Input() data: any;
  @Output() editPermission = new EventEmitter<void>();

  selectCard() {
    // 卡片选择逻辑
  }

  onEditPermission(event: Event) {
    event.stopPropagation();
    this.editPermission.emit();
  }

  getLevelColor(level: string): string {
    const colors: { [key: string]: string } = {
      'rookie': '#60a5fa',
      'silver': '#94a3b8',
      'gold': '#f59e0b',
      'platinum': '#818cf8',
      'diamond': '#22d3ee'
    };
    return colors[level] || '#60a5fa';
  }
}